#ifndef NT2_INCLUDE_FUNCTIONS_ASINH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ASINH_HPP_INCLUDED

#include <nt2/hyperbolic/include/functions/asinh.hpp>

#endif
